==> quanyi-center-api-0.0.35-20231126.095400-31-sources.jar: cn/com/duiba/quanyi/center/api/param/ccbLife/CcbLifeSettlementMonthSearchParam.java <==
package cn.com.duiba.quanyi.center.api.param.ccbLife;

import cn.com.duiba.quanyi.center.api.param.PageQuery;
import java.io.Serializable;
import java.util.Date;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

/**
 * 商户表
 * @author mybatis generator 
 * @date 2023-11-23
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class CcbLifeSettlementMonthSearchParam extends PageQuery implements Serializable {
     
    private static final long serialVersionUID = 17007079237001302L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 结算月份
     */
    private String month;

    /**
     * 商户id
     */
    private Long businessId;

    /**
     * 优惠券优惠总金额
     */
    private Long couponTotalAmount;

    /**
     * 电话号码
     */
    private Long phone;

    /**
     * 商家补贴总金额
     */
    private Long merchantSubsidyTotalAmount;

    /**
     * 机构补贴总金额
     */
    private Long institutionalSubsidyTotalAmount;

    /**
     * 政府补贴总金额
     */
    private Long governmentSubsidyTotalAmount;

    /**
     * 确认用户id
     */
    private Long accountId;

    /**
     * 确认时间
     */
    private Date confirmTime;

    /**
     * 结算总金额
     */
    private Long totalAmout;

    /**
     * 结算状态 0初始化  1数据处理中  2数据处理完成（未结算） 3已结算
     */
    private Byte settlementStatus;

    /**
     * 删除标识 （0：未删除，1：删除）默认为0
     */
    private Byte deleted;
}

==> quanyi-center-api-0.0.35-20231130.100003-84-sources.jar: cn/com/duiba/quanyi/center/api/param/ccbLife/CcbLifeSettlementMonthSearchParam.java <==
package cn.com.duiba.quanyi.center.api.param.ccbLife;

import cn.com.duiba.quanyi.center.api.param.PageQuery;
import java.io.Serializable;
import java.util.Date;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

/**
 * 商户表
 * @author mybatis generator 
 * @date 2023-11-23
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class CcbLifeSettlementMonthSearchParam extends PageQuery implements Serializable {
     
    private static final long serialVersionUID = 17007079237001302L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 结算月份
     */
    private String month;

    /**
     * 商户id
     */
    private Long businessId;

    /**
     * 优惠券优惠总金额
     */
    private Long couponTotalAmount;

    /**
     * 电话号码
     */
    private Long phone;

    /**
     * 商家补贴总金额
     */
    private Long merchantSubsidyTotalAmount;

    /**
     * 机构补贴总金额
     */
    private Long institutionalSubsidyTotalAmount;

    /**
     * 政府补贴总金额
     */
    private Long governmentSubsidyTotalAmount;

    /**
     * 确认用户id
     */
    private Long accountId;

    /**
     * 确认时间
     */
    private Date confirmTime;

    /**
     * 结算总金额
     */
    private Long totalAmout;

    /**
     * 结算状态 0初始化  1数据处理中  2数据处理完成（未结算） 3已结算
     */
    private Integer settlementStatus;

    /**
     * 删除标识 （0：未删除，1：删除）默认为0
     */
    private Integer deleted;
}
